@@ -12,6 +12,15 @@ std::string empty_body_text::p_tag()
   os << "</p:txBody>";
   return os.str();
 }
+
+std::string empty_body_text::x_tag()
+{
+  std::stringstream os;
+  os << "<xdr:txBody>";
+  os << "<a:bodyPr/><a:lstStyle/><a:p/>";
+  os << "</xdr:txBody>";
+  return os.str();
+}
 std::string empty_body_text::wps_tag()
 {
   return "<wps:bodyPr/>";
